[Glibc-bsd-commits] r5794 - in trunk/glibc-ports/kfreebsd: mips x86_64

aurel32 at alioth.debian.org aurel32 at alioth.debian.org
Tue Oct 20 13:50:24 UTC 2015


Author: aurel32
Date: 2015-10-20 13:50:24 +0000 (Tue, 20 Oct 2015)
New Revision: 5794

Modified:
   trunk/glibc-ports/kfreebsd/mips/dl-machine.h
   trunk/glibc-ports/kfreebsd/x86_64/dl-machine.h
Log:
Merge from upstream:

commit c5684fdb2badfda3bd6e973e5f933272e39e9590
Author: Joseph Myers <joseph at codesourcery.com>
Date:   Tue Nov 4 23:26:39 2014 +0000

    Don't use INTDEF/INTUSE with _dl_init (bug 14132).
    
    Continuing the removal of the obsolete INTDEF / INTUSE mechanism, this
    patch eliminates its use for _dl_init.  Since _dl_init was already
    declared with hidden visibility, creating a second hidden alias for it
    was completely pointless, so this patch replaces all uses of
    _dl_init_internal with plain _dl_init instead of using hidden_proto /
    hidden_def (which are only needed when you want a hidden alias for a
    non-hidden symbol; it's quite possible there are cases where they are
    used but don't need to be because the symbol in question is not part
    of the public ABI and is only used within a single library, so using
    attributes_hidden instead would suffice).


Modified: trunk/glibc-ports/kfreebsd/mips/dl-machine.h
===================================================================
--- trunk/glibc-ports/kfreebsd/x86_64/dl-machine.h	2015-10-20 13:47:19 UTC (rev 5793)
+++ trunk/glibc-ports/kfreebsd/x86_64/dl-machine.h	2015-10-20 13:50:24 UTC (rev 5794)
@@ -62,7 +62,7 @@
 	# Clear %rbp to mark outermost frame obviously even for constructors.\n\
 	xorl %ebp, %ebp\n\
 	# Call the function to run the initializers.\n\
-	call _dl_init_internal at PLT\n\
+	call _dl_init at PLT\n\
 	# Pass our finalizer function to the user in %rdx, as per ELF ABI draft.\n\
 	leaq _dl_fini(%rip), %rdx\n\
 	# And make sure %rdi points to argc stored on the stack.\n\




More information about the Glibc-bsd-commits mailing list
--- trunk/glibc-ports/kfreebsd/mips/dl-machine.h	2015-10-20 13:47:19 UTC (rev 5793)
+++ trunk/glibc-ports/kfreebsd/mips/dl-machine.h	2015-10-20 13:50:24 UTC (rev 5794)
@@ -78,13 +78,13 @@
 	sll $7, $5, " STRINGXP (PTRLOG) "\n\
 	" STRINGXP(PTR_ADDU) " $7, $7, $6\n\
 	" STRINGXP(PTR_ADDU) " $7, $7, " STRINGXP (PTRSIZE) " \n\
 	# Make sure the stack pointer is aligned for _dl_init_internal.\n\
 	and $2, $29, -2 * " STRINGXP(SZREG) "\n\
 	" STRINGXP(PTR_S) " $29, -" STRINGXP(SZREG) "($2)\n\
 	" STRINGXP(PTR_SUBIU) " $29, $2, 32\n\
 	" STRINGXP(SAVE_GP(16)) "\n\
 	# Call the function to run the initializers.\n\
-	jal _dl_init_internal\n\
+	jal _dl_init\n\
 	# Restore the stack pointer for _start.\n\
 	" STRINGXP(PTR_L)  " $29, 32-" STRINGXP(SZREG) "($29)\n\
 	# Pass our finalizer function to the user in $2 as per ELF ABI.\n\
@@ -78,13 +78,13 @@
 	" STRINGXP(PTR_ADDU) " $7, $7, $6\n\
 	" STRINGXP(PTR_ADDU) " $7, $7, " STRINGXP (PTRSIZE) " \n\
-	# Make sure the stack pointer is aligned for _dl_init_internal.\n\
+	# Make sure the stack pointer is aligned for _dl_init.\n\
 	and $2, $29, -2 * " STRINGXP(SZREG) "\n\
 	" STRINGXP(PTR_S) " $29, -" STRINGXP(SZREG) "($2)\n\

Modified: trunk/glibc-ports/kfreebsd/x86_64/dl-machine.h
===================================================================